==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/template/authorization/ActionFluent.java <==
package me.snowdrop.istio.mixer.template.authorization;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import me.snowdrop.istio.api.cexl.TypedValue;

public interface ActionFluent<A extends me.snowdrop.istio.mixer.template.authorization.ActionFluent<A>> extends Fluent<A>{


    public String getMethod();
    public A withMethod(String method);
    public Boolean hasMethod();
    public A withNewMethod(String arg1);
    public A withNewMethod(StringBuilder arg1);
    public A withNewMethod(StringBuffer arg1);
    public String getNamespace();
    public A withNamespace(String namespace);
    public Boolean hasNamespace();
    public A withNewNamespace(String arg1);
    public A withNewNamespace(StringBuilder arg1);
    public A withNewNamespace(StringBuffer arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);
    public A addToProperties(String key,TypedValue value);
    public A addToProperties(Map<String,TypedValue> map);
    public A removeFromProperties(String key);
    public A removeFromProperties(Map<String,TypedValue> map);
    public Map<String,TypedValue> getProperties();
    public A withProperties(Map<String,TypedValue> properties);
    public Boolean hasProperties();
    public String getService();
    public A withService(String service);
    public Boolean hasService();
    public A withNewService(String arg1);
    public A withNewService(StringBuilder arg1);
    public A withNewService(StringBuffer arg1);



}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/mixer/template/authorization/ActionFluent.java <==
package me.snowdrop.istio.mixer.template.authorization;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import me.snowdrop.istio.api.cexl.TypedValue;

public interface ActionFluent<A extends ActionFluent<A>> extends Fluent<A>{


    public String getMethod();
    public A withMethod(String method);
    public Boolean hasMethod();
    public A withNewMethod(String arg1);
    public A withNewMethod(StringBuilder arg1);
    public A withNewMethod(StringBuffer arg1);
    public String getNamespace();
    public A withNamespace(String namespace);
    public Boolean hasNamespace();
    public A withNewNamespace(String arg1);
    public A withNewNamespace(StringBuilder arg1);
    public A withNewNamespace(StringBuffer arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);
    public A addToProperties(String key,TypedValue value);
    public A addToProperties(Map<String,TypedValue> map);
    public A removeFromProperties(String key);
    public A removeFromProperties(Map<String,TypedValue> map);
    public Map<String,TypedValue> getProperties();
    public A withProperties(Map<String,TypedValue> properties);
    public Boolean hasProperties();
    public String getService();
    public A withService(String service);
    public Boolean hasService();
    public A withNewService(String arg1);
    public A withNewService(StringBuilder arg1);
    public A withNewService(StringBuffer arg1);



}
